@@ -20,14 +20,16 @@ xandikos_cleanup() {
 run_xandikos()
 {
 	PORT="$1"
-	shift 1
-	${XANDIKOS} -p${PORT} -llocalhost -d ${SERVEDIR} "$@" 2>&1 >$DAEMON_LOG &
+	METRICS_PORT="$2"
+	shift 2
+	echo "Writing daemon log to $DAEMON_LOG"
+	${XANDIKOS} --no-detect-systemd --port=${PORT} --metrics-port=${METRICS_PORT} -llocalhost -d ${SERVEDIR} "$@" 2>&1 >$DAEMON_LOG &
 	XANDIKOS_PID=$!
 	trap xandikos_cleanup 0 EXIT
 	i=0
-	while [ $i -lt 10 ]
+	while [ $i -lt 50 ]
 	do
-		if curl http://localhost:${PORT}/ >/dev/null; then
+	    if [ "$(curl http://localhost:${METRICS_PORT}/health)" = "ok" ]; then
 			break
 		fi
 		sleep 1
