@@ -23,15 +23,14 @@ https://tools.ietf.org/html/rfc4791
 """
 import datetime
 import itertools
+from zoneinfo import ZoneInfo
 
-import pytz
 from icalendar.cal import Calendar as ICalendar
 from icalendar.cal import Component, FreeBusy, component_factory
-from icalendar.prop import LocalTimezone, vDDDTypes, vPeriod
+from icalendar.prop import vDDDTypes, vPeriod
 
 from . import davcommon, webdav
-from .icalendar import (apply_time_range_vevent, as_tz_aware_ts,
-                        expand_calendar_rrule)
+from .icalendar import apply_time_range_vevent, as_tz_aware_ts, expand_calendar_rrule
 
 ET = webdav.ET
 
@@ -58,9 +57,7 @@ TRANSPARENCY_OPAQUE = "opaque"
 
 
 class Calendar(webdav.Collection):
-
-    resource_types = webdav.Collection.resource_types + [
-        CALENDAR_RESOURCE_TYPE]
+    resource_types = webdav.Collection.resource_types + [CALENDAR_RESOURCE_TYPE]
 
     def get_calendar_description(self) -> str:
         """Return the calendar description."""
@@ -169,11 +166,15 @@ class Calendar(webdav.Collection):
     def get_xmpp_uri(self):
         raise NotImplementedError(self.get_xmpp_uri)
 
+    def get_created_by(self):
+        raise NotImplementedError(self.get_created_by)
+
+    def get_updated_by(self):
+        raise NotImplementedError(self.get_updated_by)
+
 
 class Subscription:
-
-    resource_types = webdav.Collection.resource_types + [
-        SUBSCRIPTION_RESOURCE_TYPE]
+    resource_types = webdav.Collection.resource_types + [SUBSCRIPTION_RESOURCE_TYPE]
 
     def get_source_url(self):
         """Get the source URL for this calendar."""
@@ -261,8 +262,7 @@ class CalendarDescriptionProperty(webdav.Property):
         raise NotImplementedError
 
 
-def _extract_from_component(
-        incomp: Component, outcomp: Component, requested) -> None:
+def _extract_from_component(incomp: Component, outcomp: Component, requested) -> None:
     """Extract specific properties from a calendar event.
 
     Args:
@@ -310,12 +310,10 @@ def extract_from_calendar(incal, requested):
             incal = expand_calendar_rrule(incal, start, end)
         elif tag.tag == ("{%s}limit-recurrence-set" % NAMESPACE):
             # TODO(jelmer): https://github.com/jelmer/xandikos/issues/103
-            raise NotImplementedError(
-                "limit-recurrence-set is not yet implemented")
+            raise NotImplementedError("limit-recurrence-set is not yet implemented")
         elif tag.tag == ("{%s}limit-freebusy-set" % NAMESPACE):
             # TODO(jelmer): https://github.com/jelmer/xandikos/issues/104
-            raise NotImplementedError(
-                "limit-freebusy-set is not yet implemented")
+            raise NotImplementedError("limit-freebusy-set is not yet implemented")
         else:
             raise AssertionError(f"invalid element {tag!r}")
     return incal
@@ -363,7 +361,6 @@ class CalendarOrderProperty(webdav.Property):
 
 
 class CalendarMultiGetReporter(davcommon.MultiGetReporter):
-
     name = "{%s}calendar-multiget" % NAMESPACE
     resource_type = (CALENDAR_RESOURCE_TYPE, SCHEDULE_INBOX_RESOURCE_TYPE)
     data_property = CalendarDataProperty()
@@ -491,22 +488,23 @@ def extract_tzid(cal):
     return cal.subcomponents[0]["TZID"]
 
 
-def get_pytz_from_text(tztext):
+def get_timezone_from_text(tztext):
     tzid = extract_tzid(ICalendar.from_ical(tztext))
-    return pytz.timezone(tzid)
+    return ZoneInfo(tzid)
 
 
-def get_calendar_timezone(resource):
+def get_calendar_timezone(resource: Calendar):
     try:
         tztext = resource.get_calendar_timezone()
     except KeyError:
-        return LocalTimezone()
+        now = datetime.datetime.now()
+        local_now = now.astimezone()
+        return local_now.tzinfo
     else:
-        return get_pytz_from_text(tztext)
+        return get_timezone_from_text(tztext)
 
 
 class CalendarQueryReporter(webdav.Reporter):
-
     name = "{%s}calendar-query" % NAMESPACE
     resource_type = (CALENDAR_RESOURCE_TYPE, SCHEDULE_INBOX_RESOURCE_TYPE)
     data_property = CalendarDataProperty()
@@ -521,7 +519,7 @@ class CalendarQueryReporter(webdav.Reporter):
         base_href,
         base_resource,
         depth,
-        strict
+        strict,
     ):
         # TODO(jelmer): Verify that resource is a calendar
         requested = None
@@ -536,16 +534,15 @@ class CalendarQueryReporter(webdav.Reporter):
                 tztext = el.text
             else:
                 webdav.nonfatal_bad_request(
-                    f"Unknown tag {el.tag} in report {self.name}",
-                    strict
+                    f"Unknown tag {el.tag} in report {self.name}", strict
                 )
         if requested is None:
             # The CalDAV RFC says that behaviour mimicks that of PROPFIND,
             # and the WebDAV RFC says that no body implies {DAV}allprop
             # This isn't exactly an empty body, but close enough.
-            requested = ET.Element('{DAV:}allprop')
+            requested = ET.Element("{DAV:}allprop")
         if tztext is not None:
-            tz = get_pytz_from_text(tztext)
+            tz = get_timezone_from_text(tztext)
         else:
             tz = get_calendar_timezone(base_resource)
 
@@ -558,7 +555,7 @@ class CalendarQueryReporter(webdav.Reporter):
                 collection.subcollections(),
             )
 
-        async for (href, resource) in webdav.traverse_resource(
+        async for href, resource in webdav.traverse_resource(
             base_resource, base_href, depth, members=members
         ):
             # Ideally traverse_resource would only return the right things.
@@ -592,6 +589,30 @@ class CalendarColorProperty(webdav.Property):
         resource.set_calendar_color(el.text)
 
 
+class CreatedByProperty(webdav.Property):
+    """created-by property.
+    """
+
+    name = "{http://calendarserver.org/ns/}created-by"
+    resource_type = (
+        CALENDAR_RESOURCE_TYPE)
+
+    async def get_value(self, href, resource, el, environ):
+        el.text = resource.get_created_by()
+
+
+class UpdatedByProperty(webdav.Property):
+    """updated-by property.
+    """
+
+    name = "{http://calendarserver.org/ns/}updated-by"
+    resource_type = (
+        CALENDAR_RESOURCE_TYPE)
+
+    async def get_value(self, href, resource, el, environ):
+        el.text = resource.get_updated_by()
+
+
 class SupportedCalendarComponentSetProperty(webdav.Property):
     """supported-calendar-component-set property.
 
@@ -635,8 +656,7 @@ class SupportedCalendarDataProperty(webdav.Property):
             content_type,
             version,
         ) in resource.get_supported_calendar_data_types():
-            subel = ET.SubElement(
-                el, "{urn:ietf:params:xml:ns:caldav}calendar-data")
+            subel = ET.SubElement(el, "{urn:ietf:params:xml:ns:caldav}calendar-data")
             subel.set("content-type", content_type)
             subel.set("version", version)
 
@@ -909,7 +929,7 @@ def extract_freebusy(comp, tzify):
 
 
 async def iter_freebusy(resources, start, end, tzify):
-    async for (href, resource) in resources:
+    async for href, resource in resources:
         c = await calendar_from_resource(resource)
         if c is None:
             continue
@@ -941,7 +961,7 @@ class FreeBusyQueryReporter(webdav.Reporter):
         base_href,
         base_resource,
         depth,
-        strict
+        strict,
     ):
         requested = None
         for el in body:
@@ -953,7 +973,7 @@ class FreeBusyQueryReporter(webdav.Reporter):
         tz = get_calendar_timezone(base_resource)
 
         def tzify(dt):
-            return as_tz_aware_ts(dt, tz).astimezone(pytz.utc)
+            return as_tz_aware_ts(dt, tz).astimezone(ZoneInfo('UTC'))
 
         (start, end) = _parse_time_range(requested)
         ret = ICalendar()
@@ -1005,8 +1025,7 @@ class MkcalendarMethod(webdav.Method):
             href, resource, el, environ
         )
         ET.SubElement(el, "{urn:ietf:params:xml:ns:caldav}calendar")
-        await app.properties["{DAV:}resourcetype"].set_value(
-            href, resource, el)
+        await app.properties["{DAV:}resourcetype"].set_value(href, resource, el)
         if base_content_type in ("text/xml", "application/xml"):
             et = await webdav._readXmlBody(
                 request,
@@ -1017,8 +1036,8 @@ class MkcalendarMethod(webdav.Method):
             for el in et:
                 if el.tag != "{DAV:}set":
                     webdav.nonfatal_bad_request(
-                        f"Unknown tag {el.tag} in mkcalendar",
-                        app.strict)
+                        f"Unknown tag {el.tag} in mkcalendar", app.strict
+                    )
                     continue
                 propstat.extend(
                     [
@@ -1028,8 +1047,7 @@ class MkcalendarMethod(webdav.Method):
                         )
                     ]
                 )
-                ret = ET.Element(
-                    "{urn:ietf:params:xml:ns:carldav:}mkcalendar-response")
+                ret = ET.Element("{urn:ietf:params:xml:ns:carldav:}mkcalendar-response")
             for propstat_el in webdav.propstat_as_xml(propstat):
                 ret.append(propstat_el)
             return webdav._send_xml_response(
