@@ -21,14 +21,10 @@ import shutil
 import tempfile
 import unittest
 
-from xandikos.web import (
-    XandikosApp,
-    XandikosBackend,
-)
+from ..web import XandikosApp, XandikosBackend
 
 
 class WebTests(unittest.TestCase):
-
     # When changing this API, please update notes/api-stability.rst and inform
     # vdirsyncer, who rely on this API.
 
